==> haskell-commonmark-0.2.6-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark
version:              0.2.6
visibility:           public
id:                   commonmark-0.2.6-1RbBxqLy8mM4F9jmZiz1U5
key:                  commonmark-0.2.6-1RbBxqLy8mM4F9jmZiz1U5
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides the core data types and functions
    for parsing commonmark (<https://spec.commonmark.org>).
    The parser is fully commonmark-compliant and passes the test
    suite.  It is designed to be customizable and easily extensible.
    To customize the output, create an AST, or support a new output
    format, one need only define some new typeclass instances.
    It is also easy to add new syntax elements or modify existing ones.

    Accurate information about source positions is available
    for all block and inline elements.  Thus the library can be
    used to create an accurate syntax highlighter or
    an editor with live preview.

    The parser has been designed for robust performance
    even in pathological cases that tend to cause stack overflows or
    exponential slowdowns in other parsers, with parsing speed that
    varies linearly with input length.

    Related packages:

    - commonmark-extensions (which defines a number of syntax extensions)
    - commonmark-pandoc (which allows using this parser to create a Pandoc
    structure)
    - commonmark-cli (a command-line tool for converting and
    syntax-highlighting commonmark documents)

category:             Text
abi:                  fe8aa5605128febf2b919d169464fdb2
exposed:              True
exposed-modules:
    Commonmark Commonmark.Blocks Commonmark.Entity Commonmark.Html
    Commonmark.Inlines Commonmark.Parser Commonmark.ReferenceMap
    Commonmark.SourceMap Commonmark.Syntax Commonmark.Tag
    Commonmark.TokParsers Commonmark.Tokens Commonmark.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark
hs-libraries:         HScommonmark-0.2.6-1RbBxqLy8mM4F9jmZiz1U5
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unicode-data-0.6.0-GopY3DZsw763kMcI2yWlOt
    unicode-transforms-0.4.0.1-63SryqqYTJc1WO2upj7CYQ

haddock-interfaces:   /usr/share/doc/haskell-commonmark/html/commonmark.haddock
haddock-html:         /usr/share/doc/haskell-commonmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-0.2.6-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark
version:              0.2.6
visibility:           public
id:                   commonmark-0.2.6-4uIlKPjP41YC5zUGFH5zOL
key:                  commonmark-0.2.6-4uIlKPjP41YC5zUGFH5zOL
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides the core data types and functions
    for parsing commonmark (<https://spec.commonmark.org>).
    The parser is fully commonmark-compliant and passes the test
    suite.  It is designed to be customizable and easily extensible.
    To customize the output, create an AST, or support a new output
    format, one need only define some new typeclass instances.
    It is also easy to add new syntax elements or modify existing ones.

    Accurate information about source positions is available
    for all block and inline elements.  Thus the library can be
    used to create an accurate syntax highlighter or
    an editor with live preview.

    The parser has been designed for robust performance
    even in pathological cases that tend to cause stack overflows or
    exponential slowdowns in other parsers, with parsing speed that
    varies linearly with input length.

    Related packages:

    - commonmark-extensions (which defines a number of syntax extensions)
    - commonmark-pandoc (which allows using this parser to create a Pandoc
    structure)
    - commonmark-cli (a command-line tool for converting and
    syntax-highlighting commonmark documents)

category:             Text
abi:                  ce0c810e80149bd6a5eb63ba87d68385
exposed:              True
exposed-modules:
    Commonmark Commonmark.Blocks Commonmark.Entity Commonmark.Html
    Commonmark.Inlines Commonmark.Parser Commonmark.ReferenceMap
    Commonmark.SourceMap Commonmark.Syntax Commonmark.Tag
    Commonmark.TokParsers Commonmark.Tokens Commonmark.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark
hs-libraries:         HScommonmark-0.2.6-4uIlKPjP41YC5zUGFH5zOL
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unicode-data-0.6.0-AOiHTkm5r8NGcBUFdu6NG2
    unicode-transforms-0.4.0.1-H5otkoRM62V49ajJ1yQMaU

haddock-interfaces:   /usr/share/doc/haskell-commonmark/html/commonmark.haddock
haddock-html:         /usr/share/doc/haskell-commonmark/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
